Description Usage Arguments Value Examples
Convenience wrapper around head-methods from
git2r.
1 | git_HEAD(repo = ".")
|
repo |
Path to a Git repo. If unspecified, current working directory is checked to see if it is or is inside a Git repo. |
A list with components:
branch_namethe name and ...
branch_typetype (local vs. remote) of the branch whose tip HEAD currently points to
head_shathe SHA and ...
head_commitgit_commit object for the
specific commit HEAD points to
repoassociated git_repository object
git_branchassociated git_branch object
or NULL if HEAD does not exist.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.